Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(70)

Unified Diff: chrome/browser/chromeos/extensions/file_browser_handler_api.h

Issue 11826048: Revert 176015 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/json_schema_compile.gypi ('k') | chrome/browser/chromeos/extensions/file_browser_handler_api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/extensions/file_browser_handler_api.h
===================================================================
--- chrome/browser/chromeos/extensions/file_browser_handler_api.h (revision 176046)
+++ chrome/browser/chromeos/extensions/file_browser_handler_api.h (working copy)
@@ -19,14 +19,14 @@
#include "chrome/browser/extensions/extension_function.h"
class Browser;
-class FileBrowserHandlerInternalSelectFileFunction;
+class FileHandlerSelectFileFunction;
namespace file_handler {
// Interface that is used by FileBrowserHandlerInternalSelectFileFunction to
// select the file path that should be reported back to the extension function
// caller. Nobody will take the ownership of the interface implementation, so
// it should delete itself once it's done.
class FileSelector {
public:
virtual ~FileSelector() {}
@@ -48,21 +48,19 @@
// |SelectFile| will be called at most once by a single extension function.
// The interface implementation should delete itself after the extension
// function is notified of file selection result.
- virtual void SelectFile(
- const FilePath& suggested_name,
- const std::vector<std::string>& allowed_extensions,
- Browser* browser,
- FileBrowserHandlerInternalSelectFileFunction* function) = 0;
+ virtual void SelectFile(const FilePath& suggested_name,
+ const std::vector<std::string>& allowed_extensions,
+ Browser* browser,
+ FileHandlerSelectFileFunction* function) = 0;
};
// Interface that is used by FileBrowserHandlerInternalSelectFileFunction to
// create a FileSelector it can use to select a file path.
class FileSelectorFactory {
public:
virtual ~FileSelectorFactory() {}
// Creates a FileSelector instance for the
// FileBrowserHandlerInternalSelectFileFunction.
virtual FileSelector* CreateFileSelector() const = 0;
};
@@ -70,19 +68,18 @@
// The fileBrowserHandlerInternal.selectFile extension function implementation.
// See the file description for more info.
-class FileBrowserHandlerInternalSelectFileFunction
- : public AsyncExtensionFunction {
+class FileHandlerSelectFileFunction : public AsyncExtensionFunction {
public:
// Default constructor used in production code.
// It will create its own FileSelectorFactory implementation, and set the
// value of |user_gesture_check_enabled| to true.
- FileBrowserHandlerInternalSelectFileFunction();
+ FileHandlerSelectFileFunction();
// This constructor should be used only in tests to inject test file selector
// factory and to allow extension function to run even if it hasn't been
// invoked by user gesture.
// Created object will take the ownership of the |file_selector_factory|.
- FileBrowserHandlerInternalSelectFileFunction(
+ FileHandlerSelectFileFunction(
file_handler::FileSelectorFactory* file_selector_factory,
bool enable_user_gesture_check);
@@ -96,7 +93,7 @@
protected:
// The class is ref counted, so destructor should not be public.
- virtual ~FileBrowserHandlerInternalSelectFileFunction();
+ virtual ~FileHandlerSelectFileFunction() OVERRIDE;
// AsyncExtensionFunction implementation.
// Runs the extension function implementation.
« no previous file with comments | « build/json_schema_compile.gypi ('k') | chrome/browser/chromeos/extensions/file_browser_handler_api.cc » ('j') | no next file with comments »
@@ -19,14 +19,14 @@
namespace file_handler {
-// Interface that is used by FileBrowserHandlerInternalSelectFileFunction to
-// select the file path that should be reported back to the extension function
-// caller. Nobody will take the ownership of the interface implementation, so
-// it should delete itself once it's done.
+// Interface that is used by FileHandlerSelectFileFunction to select the file
+// path that should be reported back to the extension function caller.
+// Nobody will take the ownership of the interface implementation, so it should
+// delete itself once it's done.
class FileSelector {
public:
@@ -48,21 +48,19 @@
};
-// Interface that is used by FileBrowserHandlerInternalSelectFileFunction to
-// create a FileSelector it can use to select a file path.
+// Interface that is used by FileHandlerSelectFileFunction to create a
+// FileSelector it can use to select a file path.
class FileSelectorFactory {
public:
@@ -48,21 +48,19 @@
public:
virtual ~FileSelectorFactory() {}
- // Creates a FileSelector instance for the
- // FileBrowserHandlerInternalSelectFileFunction.
+ // Creates a FileSelector instance for the FileHandlerSelectFileFunction.
virtual FileSelector* CreateFileSelector() const = 0;
};

Powered by Google App Engine
This is Rietveld 408576698